VornIdRateLimitError class
429: Rate limit exceeded.
- Inheritance
-
- Object
- VornIdError
- VornIdRateLimitError
Constructors
Properties
- code → String
-
Machine-readable error code (e.g.,
MISSING_API_KEY).final -
details
→ Map<
String, dynamic> ? -
Optional structured details about the error.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
Human-readable error message.
final
- retryAfter → Duration?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited