WaveformStyle class

EKG-style waveform decoration for the result screen.

Constructors

WaveformStyle({double alpha = 0.4, double strokeWidth = 1.2})
const

Properties

alpha double
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
strokeWidth double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited